@@ -1,4 +1,5 @@
 from sklearn.metrics import precision_recall_fscore_support
+import warnings
 
 def flatten(l: list):
     """Flattens list"""
@@ -11,7 +12,7 @@ def compute_f1_scores(y_pred: list,
                       **kwargs) -> list:
     """Compute F1 Scores
 
-    Computes F1 Scores.
+    Computes F1 Scores. 
 
     Args:
         y_pred (list): predicted values.
@@ -22,8 +23,16 @@ def compute_f1_scores(y_pred: list,
     Returns:
         list: resulting F1 scores.
     """
+    assert sum([len(t) < len(p) for t, p in zip(y_true, y_pred)]) == 0, "Length of predictions must not exceed length of observed values"
 
-    # HACK: truncate observed values to match predict function.
+    # check, if some lengths of observed values exceed predicted values.
+    n_exceeds = sum([len(t) > len(p) for t, p in zip(y_true, y_pred)])
+    if n_exceeds > 0:
+        warnings.warn(f'length of observed values exceeded lengths of predicted values in {n_exceeds} cases and were truncated. Consider increasing max_len parameter for your model.')
+
+    # truncate observed values dimensions to match predicted values,
+    # this is needed if predictions have been truncated earlier in 
+    # the flow.
     y_true = [t[:len(p)] for t, p in zip(y_true, y_pred)]
     
     y_pred = flatten(y_pred)
